==> apache-maven-3.8.9-src.zip: apache-maven-3.8.9/maven-core/src/main/java/org/apache/maven/MavenExecutionException.java <==
package org.apache.maven;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

import org.apache.maven.project.ProjectBuildingException;

/**
 * @author Jason van Zyl
 */
public class MavenExecutionException
    extends Exception
{
    private File pomFile;

    public MavenExecutionException( String message, File pomFile )
    {
        super( message );
        this.pomFile = pomFile;
    }

    public MavenExecutionException( String message, File pomFile, ProjectBuildingException cause )
    {
        super( message, cause );
        this.pomFile = pomFile;
    }

    public MavenExecutionException( String message, Throwable cause )
    {
        super( message, cause );
    }

    public File getPomFile()
    {
        return pomFile;
    }
}

==> apache-maven-3.9.12-src.zip: apache-maven-3.9.12/maven-core/src/main/java/org/apache/maven/MavenExecutionException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven;

import java.io.File;

import org.apache.maven.project.ProjectBuildingException;

/**
 * @author Jason van Zyl
 */
public class MavenExecutionException extends Exception {
    private File pomFile;

    public MavenExecutionException(String message, File pomFile) {
        super(message);
        this.pomFile = pomFile;
    }

    public MavenExecutionException(String message, File pomFile, ProjectBuildingException cause) {
        super(message, cause);
        this.pomFile = pomFile;
    }

    public MavenExecutionException(String message, Throwable cause) {
        super(message, cause);
    }

    public File getPomFile() {
        return pomFile;
    }
}
